@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "doom-modeline-now-playing" "1.0.1"
+(define-package "doom-modeline-now-playing" "20250906.630"
   "Segment for Doom Modeline to show media player information."
   '((emacs         "26.1")
     (doom-modeline "3.0.0"))
   :url "https://github.com/elken/doom-modeline-now-playing"
-  :commit "c851f2642a3f8603355b86a1d86affb46fd05a4d"
-  :revdesc "c851f2642a3f"
+  :commit "aff9417faaf5f1945b9ad95f27fa777bbcf269f7"
+  :revdesc "aff9417faaf5"
   :authors '(("Ellis Kenyő" . "me@elken.dev"))
   :maintainers '(("Ellis Kenyő" . "me@elken.dev")))
